@@ -1,3 +1,4 @@
+import re
 import time
 from xml.etree import ElementTree as ET
 
@@ -7,8 +8,8 @@ from django.test.simple import DjangoTestSuiteRunner
 # use django's bundled copy of unittest2 if necessary
 from django.utils.unittest import TextTestResult, TextTestRunner
 
-
 __all__ = ['HotRunner']
+__version__ = '0.2.2'
 
 class HotRunner(DjangoTestSuiteRunner):
     """This rolls in functionality from several other test runners,
@@ -50,6 +51,15 @@ class HotRunner(DjangoTestSuiteRunner):
 
 class HotRunnerTestResult(TextTestResult):
 
+    def getDescription(self, test):
+        doc_first_line = test.shortDescription()
+        if self.descriptions and doc_first_line:           
+            return '\n'.join((str(test), doc_first_line))
+        else:
+            test = re.findall('[\w_]+', str(test))
+            template = '{testname} ({app}.{suite}.{testname})'
+            return template.format(app=test[1], suite=test[-1], testname=test[0])
+
     @property
     def xunit_filename(self):
         hxf = getattr(settings, 'HOTRUNNER_XUNIT_FILENAME', None)
